urma-cli 0.2.1

Command-line program for URMA identities, wallets, Wire, archives and Git
urma-cli-0.2.1 is not a library.

urma-cli

The urma command-line program for identities, wallets, Wire records, archives and Git workflows.

This crate is part of the URMA workspace. See the repository for the other components and project documentation.

Licensed under 0BSD.